<?php
/**
 * Plugin Name: WP Down Slack Alert - Constants
 * Description: The purpose of this plugin is to configure PHP Constants for WP Down Slack Alert plugin.
 * Version: 0.4
 * License: GPLv2
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 * Text-domain: wp-down-slack-alert
 */

defined( 'ABSPATH' ) or die( 'Cheatin&#8217; uh?' );

// Version management and Worker refresh
function who_wpdsa_plugin_version() {

	// IMPORTANT: BUMP VERSION NUMBER ON EACH RELEASE
	$who_wpdsa_version = '0.4';

	$who_wpdsa_current_version = get_option( 'who_wpdsa_version' );
	if ( false === $who_wpdsa_current_version ) {
		update_option( 'who_wpdsa_version', $who_wpdsa_version );
	} else {
		if ( version_compare( $who_wpdsa_current_version, $who_wpdsa_version, '<' ) ) {
			$filesystem = who_wpdsa_get_filesystem();
			// Remove existing file
			$filename = WPMU_PLUGIN_DIR . '/whodunit-wp-down-slack-alert-settings-worker.php';
			if ( $filesystem->exists( $filename ) ) {
				$filesystem->delete( $filename );
			}
			// Add new file
			$contents = $filesystem->get_contents( plugin_dir_path( __FILE__ ) . 'template.php' );
			if ( ! $filesystem->exists( WPMU_PLUGIN_DIR ) ) {
				$filesystem->mkdir( WPMU_PLUGIN_DIR );
			}
			if ( ! $filesystem->exists( WPMU_PLUGIN_DIR ) ) {
				return;
			}
			$filesystem->put_contents( $filename, $contents );
			update_option( 'who_wpdsa_version', $who_wpdsa_version );
		}
	}
	// If the mu-plugin was removed, recreate it.
	$filesystem = who_wpdsa_get_filesystem();
	$filename   = WPMU_PLUGIN_DIR . '/whodunit-wp-down-slack-alert-settings-worker.php';
	if ( ! $filesystem->exists( $filename ) ) {
		$contents = $filesystem->get_contents( plugin_dir_path( __FILE__ ) . 'template.php' );
		if ( ! $filesystem->exists( WPMU_PLUGIN_DIR ) ) {
			$filesystem->mkdir( WPMU_PLUGIN_DIR );
		}
		if ( ! $filesystem->exists( WPMU_PLUGIN_DIR ) ) {
			return;
		}
		$filesystem->put_contents( $filename, $contents );
	}
}
add_action( 'admin_init', 'who_wpdsa_plugin_version' );

// Plugin activation
function who_wpdsa_plugin_activation() {
	$filesystem = who_wpdsa_get_filesystem();
	$filename   = WPMU_PLUGIN_DIR . '/whodunit-wp-down-slack-alert-settings-worker.php';
	if ( $filesystem->exists( $filename ) ) {
		return;
	}
	$contents = $filesystem->get_contents( plugin_dir_path( __FILE__ ) . 'template.php' );
	if ( ! $filesystem->exists( WPMU_PLUGIN_DIR ) ) {
		$filesystem->mkdir( WPMU_PLUGIN_DIR );
	}
	if ( ! $filesystem->exists( WPMU_PLUGIN_DIR ) ) {
		return;
	}
	$filesystem->put_contents( $filename, $contents );
}
register_activation_hook( __FILE__, 'who_wpdsa_plugin_activation' );

// Plugin deactivation
function who_wpdsa_plugin_deactivation() {
	// Clean options
	delete_option( 'settings_slack_notification_disable_email' );
	delete_option( 'settings_slack_notification_channel' );
	delete_option( 'settings_slack_notification_bot_name' );
	delete_option( 'settings_slack_notification_recurrence_mail' );
	delete_option( 'settings_slack_notification_recurrence' );
	delete_option( 'settings_slack_notification_attachment_id' );
	delete_option( 'settings_slack_notification_token' );
	delete_option( 'settings_slack_notification_message_title' );
	delete_option( 'settings_slack_notification_message_footer' );
	delete_option( 'settings_slack_notification_green_disable' );
	// Remove mu-plugin files
	$filesystem = who_wpdsa_get_filesystem();
	// Remove existing file
	$filename = WPMU_PLUGIN_DIR . '/whodunit-wp-down-slack-alert-settings-worker.php';
	if ( $filesystem->exists( $filename ) ) {
		$filesystem->delete( $filename );
	}
}
register_deactivation_hook( __FILE__, 'who_wpdsa_plugin_deactivation' );

// Get filesystem function
function who_wpdsa_get_filesystem() {
	static $filesystem;
	if ( $filesystem ) {
		return $filesystem;
	}
	require_once( ABSPATH . 'wp-admin/includes/class-wp-filesystem-base.php' );
	require_once( ABSPATH . 'wp-admin/includes/class-wp-filesystem-direct.php' );

	$filesystem = new WP_Filesystem_Direct( new StdClass() );
	if ( ! defined( 'FS_CHMOD_DIR' ) ) {
		define( 'FS_CHMOD_DIR', ( @fileperms( ABSPATH ) & 0777 | 0755 ) );
	}
	if ( ! defined( 'FS_CHMOD_FILE' ) ) {
		define( 'FS_CHMOD_FILE', ( @fileperms( ABSPATH . 'index.php' ) & 0777 | 0644 ) );
	}
	return $filesystem;
}
